@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import concurrent.futures
+import contextlib
 import copy
 import logging
 import os
@@ -16,11 +17,14 @@ from dateutil import parser as dt_parser
 
 from vunnel import utils
 from vunnel.providers.rhel.rhsa_provider import AffectedRelease, CSAFRHSAProvider, OVALRHSAProvider
+from vunnel.tool import fixdate
 from vunnel.utils import http_wrapper as http
 from vunnel.utils import rpm
 from vunnel.utils.vulnerability import vulnerability_element
 
 if TYPE_CHECKING:
+    from types import TracebackType
+
     import requests
 
     from .rhsa_provider import RHSAProvider
@@ -37,8 +41,8 @@ NamespacePayload = namedtuple("NamespacePayload", ["namespace", "payload"])
 class Parser:
     __cve_rhel_product_name_base__ = "Red Hat Enterprise Linux"
     __rhel_release_pattern__ = re.compile(__cve_rhel_product_name_base__ + r"\s*(\d+)$")
+    __rhel_eus_pattern__ = re.compile(r"Red Hat Enterprise Linux (\d+\.\d+) Extended Update Support")
     __summary_url__ = "https://access.redhat.com/hydra/rest/securitydata/cve.json"
-    __rhsa_url__ = "https://access.redhat.com/hydra/rest/securitydata/oval/{}.json"
     __last_synced_filename__ = "last_synced"
     __cve_download_error_filename__ = "failed_cves"
     __cve_filename_regex__ = re.compile("CVE-[0-9]+-[0-9]+")
@@ -53,15 +57,20 @@ class Parser:
     def __init__(  # noqa: PLR0913
         self,
         workspace,
+        fixdater: fixdate.Finder | None = None,
         download_timeout=None,
         max_workers=None,
         full_sync_interval=None,
         skip_namespaces=None,
         rhsa_provider_type=None,
+        ignore_hydra_errors: bool = False,
         logger=None,
         skip_download: bool = False,
     ):
         self.workspace = workspace
+        if not fixdater:
+            fixdater = fixdate.default_finder(workspace)
+        self.fixdater = fixdater
         self.cve_dir_path = os.path.join(workspace.input_path, self.__cve_dir_name__)
         self.rhsa_dir_path = os.path.join(workspace.input_path, self.__rhsa_dir_name__)
         self.download_timeout = download_timeout if isinstance(download_timeout, int) else 125
@@ -71,6 +80,7 @@ class Parser:
         self.rhsa_dict = None
         self.rhsa_provider: RHSAProvider | None = None
         self.rhsa_provider_type: str | None = rhsa_provider_type
+        self.ignore_hydra_errors = ignore_hydra_errors
         self.skip_download = skip_download
 
         self.urls = [self.__summary_url__]
@@ -79,6 +89,13 @@ class Parser:
             logger = logging.getLogger(self.__class__.__name__)
         self.logger = logger
 
+    def __enter__(self) -> Parser:
+        self.fixdater.__enter__()
+        return self
+
+    def __exit__(self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None) -> None:
+        self.fixdater.__exit__(exc_type, exc_val, exc_tb)
+
     def _download_minimal_cves(self, page, limit=1000):
         path_params = {"per_page": str(limit), "page": page, "product": self.__cve_rhel_product_name_base__}
 
@@ -144,28 +161,27 @@ class Parser:
 
     def _download_minimal_cve_pages(self) -> int:
         dir_path = os.path.join(self.cve_dir_path, self.__min_pages_dir_name__)
+        backup_dir_path = os.path.join(self.cve_dir_path, self.__min_pages_dir_name__ + "_backup")
 
-        # clear all existing records
-        utils.silent_remove(dir_path, tree=True)
-        os.makedirs(dir_path)
+        # use context manager to enforce cleanup of backup dir and # restore it if necessary
+        with handle_hydra_data(self.ignore_hydra_errors, dir_path, backup_dir_path, self.logger):
+            page = 0
+            count = 0
+            while True:
+                page += 1
+                results = self._download_minimal_cves(page)
 
-        page = 0
-        count = 0
-        while True:
-            page += 1
-            results = self._download_minimal_cves(page)
+                if not isinstance(results, list) or not results:
+                    break
 
-            if not isinstance(results, list) or not results:
-                break
+                min_cve_file = os.path.join(dir_path, f"{page}.json")
 
-            min_cve_file = os.path.join(dir_path, f"{page}.json")
+                count += len(results)
 
-            count += len(results)
+                with open(min_cve_file, "wb") as fp:
+                    fp.write(orjson.dumps(results))
 
-            with open(min_cve_file, "wb") as fp:
-                fp.write(orjson.dumps(results))
-
-        return count
+            return count
 
     def enumerate_minimal_cve_pages(self):
         dir_path = os.path.join(self.cve_dir_path, self.__min_pages_dir_name__)
@@ -227,6 +243,11 @@ class Parser:
         utils.silent_remove(os.path.join(self.cve_dir_path, self.__last_synced_filename__))
         utils.silent_remove(os.path.join(self.cve_dir_path, self.__cve_download_error_filename__))
 
+        if self.skip_download:
+            self.logger.warning("skip download requested, but fix date finder does not support skipping download")
+        else:
+            self.fixdater.download()
+
         count = self._download_minimal_cve_pages()
 
         self.logger.info(f"downloading and processing {count} CVEs")
@@ -410,15 +431,8 @@ class Parser:
             # first pass to just parse affected releases and construct a list of objects
             for item in ars:
                 try:
-                    match = re.match(
-                        self.__rhel_release_pattern__,
-                        item.get("product_name", None),
-                    )
-                    if not match:
-                        continue
-
-                    platform = match.group(1)
-                    if not platform:  # track even deny-listed platforms here, filter them out later
+                    platform = self._parse_platform(item.get("product_name", None))
+                    if not platform:
                         continue
 
                     ar_obj = AffectedRelease(platform=platform)
@@ -572,21 +586,14 @@ class Parser:
 
         return package_name, module
 
-    def _parse_package_state(self, cve_id: str, content) -> list[FixedIn]:  # noqa: C901
+    def _parse_package_state(self, cve_id: str, content) -> list[FixedIn]:
         affected: list[FixedIn] = []
         out_of_support: list[FixedIn] = []  # Track items out of support to be able to add them if others are affected
         pss = content.get("package_state", [])
 
         for item in pss:
             try:
-                match = re.match(
-                    Parser.__rhel_release_pattern__,
-                    item.get("product_name", None),
-                )
-                if not match:
-                    continue
-
-                platform = match.group(1)
+                platform = self._parse_platform(item.get("product_name", None))
                 if not platform or f"{namespace}:{platform}" in self.skip_namespaces:
                     continue
 
@@ -645,6 +652,26 @@ class Parser:
 
         return affected + out_of_support
 
+    def _parse_platform(self, product_name: str | None) -> str | None:
+        is_eus = False
+        match = re.match(
+            self.__rhel_release_pattern__,
+            product_name,
+        )
+        if not match:
+            match = re.match(
+                self.__rhel_eus_pattern__,
+                product_name,
+            )
+            if not match:
+                return None
+            is_eus = True
+
+        platform = match.group(1)
+        if platform and is_eus:
+            platform = f"{platform}+eus"
+        return platform
+
     def _parse_cvss3(self, cvss3: dict | None) -> RHELCVSS3 | None:
         if not cvss3:
             return None
@@ -760,16 +787,33 @@ class Parser:
                                 },
                             )
 
-                    v["Vulnerability"]["FixedIn"].append(
-                        {
-                            "Name": artifact.package,
-                            "Version": artifact.version,
-                            "Module": artifact.module,
-                            "VersionFormat": "rpm",  # hard code version format for now
-                            "NamespaceName": ns,
-                            "VendorAdvisory": a,
-                        },
+                    fix_version = artifact.version
+                    package_name = artifact.package
+
+                    record = {
+                        "Name": package_name,
+                        "Version": fix_version or "None",
+                        "Module": artifact.module,
+                        "VersionFormat": "rpm",  # hard code version format for now
+                        "NamespaceName": ns,
+                        "VendorAdvisory": a,
+                    }
+
+                    result = self.fixdater.best(
+                        vuln_id=cve_id,
+                        cpe_or_package=package_name,
+                        fix_version=fix_version,
+                        ecosystem=ns,
+                        # TODO: consider getting issued date from CSAF or OVAL data as possible candidate
+                        # candidates=[]
                     )
+                    if result:
+                        record["Available"] = {
+                            "date": result.date.isoformat(),
+                            "kind": result.kind,
+                        }
+
+                    v["Vulnerability"]["FixedIn"].append(record)
 
                 results.append(NamespacePayload(namespace=ns, payload=v))
 
@@ -841,3 +885,32 @@ class RHELCVSS3:
                 "base_severity": self.cvss3_obj.severities()[0],
             },
         }
+
+
+# return a context manager function that uses ignore_hydra_errors to handle restoring the backup dir
+@contextlib.contextmanager
+def handle_hydra_data(ignore_hydra_errors: bool, dir_path: str, backup_dir_path: str, logger):
+    if ignore_hydra_errors:
+        # move existing min pages dir to temp dir in case we need to restore it
+        utils.silent_remove(backup_dir_path, tree=True)
+        if os.path.exists(dir_path):
+            logger.debug(f"moving existing {dir_path} to {backup_dir_path}")
+            utils.move_dir(dir_path, backup_dir_path)
+        else:
+            logger.debug(f"no existing {dir_path} to move, starting fresh")
+    else:
+        # clear all existing records
+        utils.silent_remove(dir_path, tree=True)
+
+    os.makedirs(dir_path)
+
+    try:
+        yield
+    except Exception as e:
+        logger.error(f"error processing minimal CVE pages: {e}")
+        if ignore_hydra_errors:
+            logger.debug("restoring backup directory")
+            utils.silent_remove(dir_path, tree=True)
+            utils.move_dir(backup_dir_path, dir_path)
+        else:
+            raise
