@@ -12,10 +12,13 @@ from typing import TYPE_CHECKING, Any
 
 import orjson
 
+from vunnel.tool import fixdate
+
 from .git import GitWrapper
 
 if TYPE_CHECKING:
     from collections.abc import Generator
+    from types import TracebackType
 
     from vunnel.workspace import Workspace
 
@@ -87,6 +90,7 @@ ubuntu_version_names = {
     "noble": "24.04",
     "oracular": "24.10",
     "plucky": "25.04",
+    "questing": "25.10",
 }
 
 # driver workspace
@@ -152,6 +156,13 @@ class FixedIn(JsonifierMixin):
         self.VersionFormat = None
         self.Version = None
         self.VendorAdvisory = None
+        self.Available = None
+
+
+class FixAvailability(JsonifierMixin):
+    def __init__(self):
+        self.Date = None
+        self.Kind = None
 
 
 class Severity(enum.IntEnum):
@@ -471,7 +482,7 @@ def parse_severity_from_priority(cve: CVEFile) -> Severity:
     return getattr(Severity, severity)
 
 
-def map_parsed(parsed_cve: CVEFile, logger: logging.Logger | None = None):  # noqa: C901, PLR0912
+def map_parsed(parsed_cve: CVEFile, fixdater: fixdate.Finder, logger: logging.Logger | None = None):  # noqa: C901, PLR0912, PLR0915
     """
     Maps a parsed CVE dict into a Vulnerability object.
 
@@ -546,6 +557,18 @@ def map_parsed(parsed_cve: CVEFile, logger: logging.Logger | None = None):  # no
                     continue
                     # Strange condition where a release was done but no version found. In this case, we'll omit the FixedIn record.
 
+                result = fixdater.best(
+                    vuln_id=r.Name,
+                    cpe_or_package=pkg.Name,
+                    fix_version=pkg.Version,
+                    ecosystem=r.NamespaceName,
+                )
+                if result:
+                    fa = FixAvailability()
+                    fa.Date = result.date.isoformat()
+                    fa.Kind = result.kind
+                    pkg.Available = fa
+
             else:
                 pkg.Version = "None"
                 # Set NoAdvisory to true so that `wont-fix` status gets set on
@@ -630,6 +653,7 @@ class Parser:
     def __init__(  # noqa: PLR0913
         self,
         workspace: Workspace,
+        fixdater: fixdate.Finder | None = None,
         logger: logging.Logger | None = None,
         additional_versions: dict[str, str] | None = None,
         enable_rev_history: bool = True,
@@ -637,6 +661,9 @@ class Parser:
         git_url: str = default_git_url,
         git_branch: str = default_git_branch,
     ):
+        if not fixdater:
+            fixdater = fixdate.default_finder(workspace)
+        self.fixdater = fixdater
         self.vc_workspace = os.path.join(workspace.input_path, self._vc_working_dir)
         # TODO: tech debt: this should use the results workspace with the correct schema-aware envelope
         self.norm_workspace = os.path.join(workspace.input_path, self._normalized_cve_dir)
@@ -653,7 +680,16 @@ class Parser:
         self.enable_rev_history = enable_rev_history
         self._max_workers = max_workers
 
+    def __enter__(self) -> Parser:
+        self.fixdater.__enter__()
+        return self
+
+    def __exit__(self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None) -> None:
+        self.fixdater.__exit__(exc_type, exc_val, exc_tb)
+
     def fetch(self, skip_if_exists=False):
+        self.fixdater.download()
+
         # setup merged workspace
         if not os.path.exists(self.norm_workspace):
             os.makedirs(self.norm_workspace)
@@ -673,7 +709,7 @@ class Parser:
         # load merged state and map it to vulnerabilities
         self.logger.info("begin loading processed CVE content and transforming into vulnerabilities")
         for merged_cve in self._merged_cve_iterator():
-            yield from map_parsed(merged_cve, self.logger)
+            yield from map_parsed(merged_cve, self.fixdater, self.logger)
         self.logger.info("finish loading processed CVE content and transforming into vulnerabilities")
 
     def _process_data(self, vc_dir: str, to_rev: str, from_rev: str | None = None):  # noqa: C901
