@@ -1,16 +1,12 @@
 from __future__ import annotations
 
-import json
-import os
 import shutil
 
-import pytest
-from vunnel import result, workspace
+from vunnel import result
 from vunnel.providers.chainguard import Config, Provider
-from vunnel.providers.wolfi import parser
 
 
-def test_provider_schema(helpers, disable_get_requests):
+def test_provider_schema(helpers, disable_get_requests, auto_fake_fixdate_finder):
     workspace = helpers.provider_workspace_helper(name=Provider.name())
 
     c = Config()
@@ -26,7 +22,7 @@ def test_provider_schema(helpers, disable_get_requests):
     assert workspace.result_schemas_valid(require_entries=True)
 
 
-def test_provider_via_snapshot(helpers, disable_get_requests, monkeypatch):
+def test_provider_via_snapshot(helpers, disable_get_requests, monkeypatch, auto_fake_fixdate_finder):
     workspace = helpers.provider_workspace_helper(
         name=Provider.name(),
         input_fixture="test-fixtures/input",
